@@ -9,14 +9,14 @@ import (
 )
 
 func EndpointResolver(endpoint string) aws.EndpointResolverWithOptionsFunc {
-	return aws.EndpointResolverWithOptionsFunc(func(_, reg string, options ...interface{}) (aws.Endpoint, error) {
+	return func(_, reg string, _ ...any) (aws.Endpoint, error) {
 		return aws.Endpoint{
 			PartitionID:   "aws",
 			URL:           endpoint,
 			SigningRegion: reg,
 			Source:        aws.EndpointSourceCustom,
 		}, nil
-	})
+	}
 }
 
 func MakeAWSOptions(region, endpoint string) []func(*awsconfig.LoadOptions) error {
