@@ -1,23 +1,24 @@
 package dpkg
 
 import (
-	"context"
-	"github.com/aquasecurity/trivy/pkg/mapfs"
 	"os"
 	"path/filepath"
 	"sort"
 	"testing"
 
+	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
+
 	"github.com/aquasecurity/trivy/pkg/fanal/analyzer"
 	"github.com/aquasecurity/trivy/pkg/fanal/types"
-	"github.com/stretchr/testify/assert"
+	"github.com/aquasecurity/trivy/pkg/mapfs"
 )
 
 func Test_dpkgAnalyzer_Analyze(t *testing.T) {
 	tests := []struct {
 		name string
 		// testFiles contains path in testdata and path in OS
-		// e.g. tar.list => var/lib/dpkg/info/tar.list
+		// e.g. tar.md5sums => var/lib/dpkg/info/tar.md5sums
 		testFiles map[string]string
 		want      *analyzer.AnalysisResult
 		wantErr   bool
@@ -622,8 +623,9 @@ func Test_dpkgAnalyzer_Analyze(t *testing.T) {
 								Arch:       "amd64",
 							},
 							{
-								ID:         "libgpg-error0@1.27-6",
-								Name:       "libgpg-error0",
+								ID:   "libgpg-error0@1.27-6",
+								Name: "libgpg-error0",
+
 								Version:    "1.27",
 								Release:    "6",
 								SrcName:    "libgpg-error",
@@ -1370,7 +1372,9 @@ func Test_dpkgAnalyzer_Analyze(t *testing.T) {
 						Packages: []types.Package{
 							{
 								ID: "apt@1.6.3ubuntu0.1", Name: "apt", Version: "1.6.3ubuntu0.1",
-								SrcName: "apt", SrcVersion: "1.6.3ubuntu0.1", Maintainer: "Ubuntu Developers <ubuntu-devel-discuss@lists.ubuntu.com>", Arch: "amd64"},
+								SrcName: "apt", SrcVersion: "1.6.3ubuntu0.1",
+								Maintainer: "Ubuntu Developers <ubuntu-devel-discuss@lists.ubuntu.com>", Arch: "amd64",
+							},
 						},
 					},
 				},
@@ -1416,12 +1420,11 @@ func Test_dpkgAnalyzer_Analyze(t *testing.T) {
 			},
 		},
 		{
-			name:      "info list",
-			testFiles: map[string]string{"./testdata/tar.list": "var/lib/dpkg/info/tar.list"},
+			name:      "md5sums",
+			testFiles: map[string]string{"./testdata/tar.md5sums": "var/lib/dpkg/info/tar.md5sums"},
 			want: &analyzer.AnalysisResult{
 				SystemInstalledFiles: []string{
-					"/bin/tar",
-					"/etc",
+					"/usr/bin/tar",
 					"/usr/lib/mime/packages/tar",
 					"/usr/sbin/rmt-tar",
 					"/usr/sbin/tarcat",
@@ -1434,7 +1437,6 @@ func Test_dpkgAnalyzer_Analyze(t *testing.T) {
 					"/usr/share/man/man1/tar.1.gz",
 					"/usr/share/man/man1/tarcat.1.gz",
 					"/usr/share/man/man8/rmt-tar.8.gz",
-					"/etc/rmt",
 				},
 			},
 		},
@@ -1442,21 +1444,21 @@ func Test_dpkgAnalyzer_Analyze(t *testing.T) {
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
 			a, err := newDpkgAnalyzer(analyzer.AnalyzerOptions{})
-			assert.NoError(t, err)
-			ctx := context.Background()
+			require.NoError(t, err)
+			ctx := t.Context()
 
 			mfs := mapfs.New()
 			for testPath, osPath := range tt.testFiles {
 				err = mfs.MkdirAll(filepath.Dir(osPath), os.ModePerm)
-				assert.NoError(t, err)
+				require.NoError(t, err)
 				err = mfs.WriteFile(osPath, testPath)
-				assert.NoError(t, err)
+				require.NoError(t, err)
 			}
 
 			got, err := a.PostAnalyze(ctx, analyzer.PostAnalysisInput{
 				FS: mfs,
 			})
-			assert.NoError(t, err)
+			require.NoError(t, err)
 
 			// Sort the result for consistency
 			for i := range got.PackageInfos {
@@ -1484,10 +1486,20 @@ func Test_dpkgAnalyzer_Required(t *testing.T) {
 			filePath: "var/lib/dpkg/status.d/gcc",
 			want:     true,
 		},
+		{
+			name:     "*.md5sums file in status dir",
+			filePath: "var/lib/dpkg/status.d/base-files.md5sums",
+			want:     true,
+		},
+		{
+			name:     "*.md5sums file in info dir",
+			filePath: "var/lib/dpkg/info/bash.md5sums",
+			want:     true,
+		},
 		{
 			name:     "list file",
 			filePath: "var/lib/dpkg/info/bash.list",
-			want:     true,
+			want:     false,
 		},
 		{
 			name:     "available file",
@@ -1496,14 +1508,14 @@ func Test_dpkgAnalyzer_Required(t *testing.T) {
 		},
 		{
 			name:     "sad path",
-			filePath: "var/lib/dpkg/status/bash.list",
+			filePath: "var/lib/dpkg/status/bash.md5sums",
 			want:     false,
 		},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
 			a, err := newDpkgAnalyzer(analyzer.AnalyzerOptions{})
-			assert.NoError(t, err)
+			require.NoError(t, err)
 			got := a.Required(tt.filePath, nil)
 			assert.Equal(t, tt.want, got)
 		})
