@@ -6,6 +6,7 @@ import (
 	"crypto/sha256"
 	"errors"
 	"io/fs"
+	"net/url"
 	"os"
 	"path"
 	"path/filepath"
@@ -154,7 +155,7 @@ func extractGitInfo(dir string) (bool, artifact.RepoMetadata, error) {
 		remoteConfig, err = repo.Remote("origin")
 	}
 	if err == nil && len(remoteConfig.Config().URLs) > 0 {
-		metadata.RepoURL = remoteConfig.Config().URLs[0]
+		metadata.RepoURL = sanitizeRemoteURL(remoteConfig.Config().URLs[0])
 	}
 
 	// Check if repository is clean for caching purposes
@@ -190,10 +191,11 @@ func (a Artifact) Inspect(ctx context.Context) (artifact.Reference, error) {
 			// Cache hit
 			a.logger.DebugContext(ctx, "Cache hit", log.String("key", cacheKey))
 			return artifact.Reference{
-				Name:    cmp.Or(a.artifactOption.Original, a.rootPath),
-				Type:    a.artifactOption.Type,
-				ID:      cacheKey,
-				BlobIDs: []string{cacheKey},
+				Name:         cmp.Or(a.artifactOption.Original, a.rootPath),
+				Type:         a.artifactOption.Type,
+				ID:           cacheKey,
+				BlobIDs:      []string{cacheKey},
+				RepoMetadata: a.repoMetadata,
 			}, nil
 		}
 	}
@@ -360,3 +362,20 @@ func (a Artifact) calcCacheKey() (string, error) {
 	d := digest.NewDigest(digest.SHA256, h)
 	return d.String(), nil
 }
+
+// sanitizeRemoteURL removes credentials (userinfo) from URLs.
+func sanitizeRemoteURL(gitUrl string) string {
+	// Only attempt sanitization for URLs with an explicit scheme.
+	if !strings.Contains(gitUrl, "://") {
+		return gitUrl
+	}
+
+	// Try URL parsing first.
+	if u, err := url.Parse(gitUrl); err == nil {
+		// Clear userinfo (username:password)
+		u.User = nil
+		gitUrl = u.String()
+	}
+
+	return gitUrl
+}
