@@ -3,19 +3,16 @@ package daemon
 import (
 	"testing"
 
-	"github.com/stretchr/testify/assert"
-	"github.com/stretchr/testify/require"
-
-	"github.com/docker/docker/api/types"
 	"github.com/google/go-containerregistry/pkg/name"
 	v1 "github.com/google/go-containerregistry/pkg/v1"
+	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestDockerImage(t *testing.T) {
 	type fields struct {
-		Image   v1.Image
-		opener  opener
-		inspect types.ImageInspect
+		Image  v1.Image
+		opener opener
 	}
 	tests := []struct {
 		name      string
