@@ -5,8 +5,8 @@ import (
 
 	"github.com/samber/lo"
 
-	defsecRules "github.com/aquasecurity/defsec/pkg/rules"
 	"github.com/aquasecurity/trivy/pkg/fanal/types"
+	iacRules "github.com/aquasecurity/trivy/pkg/iac/rules"
 )
 
 var (
@@ -49,6 +49,7 @@ var (
 	CategoryHubSpot              = types.SecretRuleCategory("HubSpot")
 	CategoryIntercom             = types.SecretRuleCategory("Intercom")
 	CategoryIonic                = types.SecretRuleCategory("Ionic")
+	CategoryJWT                  = types.SecretRuleCategory("JWT")
 	CategoryLinear               = types.SecretRuleCategory("Linear")
 	CategoryLob                  = types.SecretRuleCategory("Lob")
 	CategoryMailchimp            = types.SecretRuleCategory("Mailchimp")
@@ -58,6 +59,7 @@ var (
 	CategoryNewRelic             = types.SecretRuleCategory("NewRelic")
 	CategoryNpm                  = types.SecretRuleCategory("Npm")
 	CategoryPlanetscale          = types.SecretRuleCategory("Planetscale")
+	CategoryPrivatePackagist     = types.SecretRuleCategory("Private Packagist")
 	CategoryPostman              = types.SecretRuleCategory("Postman")
 	CategoryPulumi               = types.SecretRuleCategory("Pulumi")
 	CategoryRubyGems             = types.SecretRuleCategory("RubyGems")
@@ -67,22 +69,29 @@ var (
 	CategoryLinkedIn             = types.SecretRuleCategory("LinkedIn")
 	CategoryTwitch               = types.SecretRuleCategory("Twitch")
 	CategoryTypeform             = types.SecretRuleCategory("Typeform")
+	CategoryDocker               = types.SecretRuleCategory("Docker")
+	CategoryHuggingFace          = types.SecretRuleCategory("HuggingFace")
 )
 
 // Reusable regex patterns
 const (
-	quote       = `["']?`
-	connect     = `\s*(:|=>|=)\s*`
-	startSecret = `(^|\s+)`
-	endSecret   = `(\s+|$)`
+	quote     = `["']?`
+	connect   = `\s*(:|=>|=)?\s*`
+	endSecret = `[.,]?(\s+|$)`
+	startWord = "([^0-9a-zA-Z]|^)"
 
-	aws = `(aws)?_?`
+	aws = `aws_?`
 )
 
 // This function is exported for trivy-plugin-aqua purposes only
-func GetSecretRulesMetadata() []defsecRules.Check {
-	return lo.Map(builtinRules, func(rule Rule, i int) defsecRules.Check {
-		return defsecRules.Check{
+func GetBuiltinRules() []Rule {
+	return builtinRules
+}
+
+// This function is exported for trivy-plugin-aqua purposes only
+func GetSecretRulesMetadata() []iacRules.Check {
+	return lo.Map(builtinRules, func(rule Rule, _ int) iacRules.Check {
+		return iacRules.Check{
 			Name:        rule.ID,
 			Description: rule.Title,
 		}
@@ -95,7 +104,7 @@ var builtinRules = []Rule{
 		Category:        CategoryAWS,
 		Severity:        "CRITICAL",
 		Title:           "AWS Access Key ID",
-		Regex:           MustCompile(fmt.Sprintf(`%s(?P<secret>(A3T[A-Z0-9]|AKIA|AGPA|AIDA|AROA|AIPA|ANPA|ANVA|ASIA)[A-Z0-9]{16})%s%s`, quote, quote, endSecret)),
+		Regex:           MustCompileWithoutWordPrefix(fmt.Sprintf(`(?P<secret>(A3T[A-Z0-9]|AKIA|AGPA|AIDA|AROA|AIPA|ANPA|ANVA|ASIA)[A-Z0-9]{16})%s%s`, quote, endSecret)),
 		SecretGroupName: "secret",
 		Keywords:        []string{"AKIA", "AGPA", "AIDA", "AROA", "AIPA", "ANPA", "ANVA", "ASIA"},
 	},
@@ -104,56 +113,79 @@ var builtinRules = []Rule{
 		Category:        CategoryAWS,
 		Severity:        "CRITICAL",
 		Title:           "AWS Secret Access Key",
-		Regex:           MustCompile(fmt.Sprintf(`(?i)%s%s%s(secret)?_?(access)?_?key%s%s%s(?P<secret>[A-Za-z0-9\/\+=]{40})%s%s`, startSecret, quote, aws, quote, connect, quote, quote, endSecret)),
+		Regex:           MustCompile(fmt.Sprintf(`(?i)%s%s(sec(ret)?)?_?(access)?_?key%s%s%s(?P<secret>[A-Za-z0-9\/\+=]{40})%s%s`, quote, aws, quote, connect, quote, quote, endSecret)),
 		SecretGroupName: "secret",
 		Keywords:        []string{"key"},
 	},
 	{
-		ID:       "github-pat",
-		Category: CategoryGitHub,
-		Title:    "GitHub Personal Access Token",
-		Severity: "CRITICAL",
-		Regex:    MustCompile(`ghp_[0-9a-zA-Z]{36}`),
-		Keywords: []string{"ghp_"},
+		ID:              "github-pat",
+		Category:        CategoryGitHub,
+		Title:           "GitHub Personal Access Token",
+		Severity:        "CRITICAL",
+		Regex:           MustCompileWithoutWordPrefix(`?P<secret>ghp_[0-9a-zA-Z]{36}`),
+		SecretGroupName: "secret",
+		Keywords:        []string{"ghp_"},
 	},
 	{
-		ID:       "github-oauth",
-		Category: CategoryGitHub,
-		Title:    "GitHub OAuth Access Token",
-		Severity: "CRITICAL",
-		Regex:    MustCompile(`gho_[0-9a-zA-Z]{36}`),
-		Keywords: []string{"gho_"},
+		ID:              "github-oauth",
+		Category:        CategoryGitHub,
+		Title:           "GitHub OAuth Access Token",
+		Severity:        "CRITICAL",
+		Regex:           MustCompileWithoutWordPrefix(`?P<secret>gho_[0-9a-zA-Z]{36}`),
+		SecretGroupName: "secret",
+		Keywords:        []string{"gho_"},
 	},
 	{
-		ID:       "github-app-token",
-		Category: CategoryGitHub,
-		Title:    "GitHub App Token",
-		Severity: "CRITICAL",
-		Regex:    MustCompile(`(ghu|ghs)_[0-9a-zA-Z]{36}`),
-		Keywords: []string{"ghu_", "ghs_"},
+		ID:              "github-app-token",
+		Category:        CategoryGitHub,
+		Title:           "GitHub App Token",
+		Severity:        "CRITICAL",
+		Regex:           MustCompileWithoutWordPrefix(`?P<secret>(ghu|ghs)_[0-9a-zA-Z]{36}`),
+		SecretGroupName: "secret",
+		Keywords:        []string{"ghu_", "ghs_"},
 	},
 	{
-		ID:       "github-refresh-token",
-		Category: CategoryGitHub,
-		Title:    "GitHub Refresh Token",
-		Severity: "CRITICAL",
-		Regex:    MustCompile(`ghr_[0-9a-zA-Z]{76}`),
-		Keywords: []string{"ghr_"},
+		ID:              "github-refresh-token",
+		Category:        CategoryGitHub,
+		Title:           "GitHub Refresh Token",
+		Severity:        "CRITICAL",
+		Regex:           MustCompileWithoutWordPrefix(`?P<secret>ghr_[0-9a-zA-Z]{76}`),
+		SecretGroupName: "secret",
+		Keywords:        []string{"ghr_"},
 	},
 	{
-		ID:       "gitlab-pat",
-		Category: CategoryGitLab,
-		Title:    "GitLab Personal Access Token",
+		ID:       "github-fine-grained-pat",
+		Category: CategoryGitHub,
+		Title:    "GitHub Fine-grained personal access tokens",
 		Severity: "CRITICAL",
-		Regex:    MustCompile(`glpat-[0-9a-zA-Z\-\_]{20}`),
-		Keywords: []string{"glpat-"},
+		Regex:    MustCompile(`github_pat_[a-zA-Z0-9]{22}_[a-zA-Z0-9]{59}`),
+		Keywords: []string{"github_pat_"},
+	},
+	{
+		ID:              "gitlab-pat",
+		Category:        CategoryGitLab,
+		Title:           "GitLab Personal Access Token",
+		Severity:        "CRITICAL",
+		Regex:           MustCompileWithoutWordPrefix(`?P<secret>glpat-[0-9a-zA-Z\-\_]{20}`),
+		SecretGroupName: "secret",
+		Keywords:        []string{"glpat-"},
+	},
+	{
+		// cf. https://huggingface.co/docs/hub/en/security-tokens
+		ID:              "hugging-face-access-token",
+		Category:        CategoryHuggingFace,
+		Severity:        "CRITICAL",
+		Title:           "Hugging Face Access Token",
+		Regex:           MustCompileWithoutWordPrefix(`?P<secret>hf_[A-Za-z0-9]{34,40}`),
+		SecretGroupName: "secret",
+		Keywords:        []string{"hf_"},
 	},
 	{
 		ID:              "private-key",
 		Category:        CategoryAsymmetricPrivateKey,
 		Title:           "Asymmetric Private Key",
 		Severity:        "HIGH",
-		Regex:           MustCompile(`(?i)-----\s*?BEGIN[ A-Z0-9_-]*?PRIVATE KEY( BLOCK)?\s*?-----[\s]*?(?P<secret>[\sA-Za-z0-9=+/\\\r\n]+)[\s]*?-----\s*?END[ A-Z0-9_-]*? PRIVATE KEY( BLOCK)?\s*?-----`),
+		Regex:           MustCompile(`(?i)-----\s*?BEGIN[ A-Z0-9_-]*?PRIVATE KEY( BLOCK)?\s*?-----[\s]*?(?P<secret>[A-Za-z0-9=+/\\][A-Za-z0-9=+/\\\s]{30,}[A-Za-z0-9=+/\\])[\s]*?-----\s*?END[ A-Z0-9_-]*? PRIVATE KEY( BLOCK)?\s*?-----`),
 		SecretGroupName: "secret",
 		Keywords:        []string{"-----"},
 	},
@@ -166,28 +198,31 @@ var builtinRules = []Rule{
 		Keywords: []string{"shpss_", "shpat_", "shpca_", "shppa_"},
 	},
 	{
-		ID:       "slack-access-token",
-		Category: CategorySlack,
-		Title:    "Slack token",
-		Severity: "HIGH",
-		Regex:    MustCompile(`xox[baprs]-([0-9a-zA-Z]{10,48})`),
-		Keywords: []string{"xoxb-", "xoxa-", "xoxp-", "xoxr-", "xoxs-"},
+		ID:              "slack-access-token",
+		Category:        CategorySlack,
+		Title:           "Slack token",
+		Severity:        "HIGH",
+		Regex:           MustCompileWithoutWordPrefix(`?P<secret>xox[baprs]-([0-9a-zA-Z]{10,48})`),
+		SecretGroupName: "secret",
+		Keywords:        []string{"xoxb-", "xoxa-", "xoxp-", "xoxr-", "xoxs-"},
 	},
 	{
-		ID:       "stripe-publishable-token",
-		Category: CategoryStripe,
-		Title:    "Stripe Publishable Key",
-		Severity: "LOW",
-		Regex:    MustCompile(`(?i)pk_(test|live)_[0-9a-z]{10,32}`),
-		Keywords: []string{"pk_test_", "pk_live_"},
+		ID:              "stripe-publishable-token",
+		Category:        CategoryStripe,
+		Title:           "Stripe Publishable Key",
+		Severity:        "LOW",
+		Regex:           MustCompileWithoutWordPrefix(`?P<secret>(?i)pk_(test|live)_[0-9a-z]{10,32}`),
+		SecretGroupName: "secret",
+		Keywords:        []string{"pk_test_", "pk_live_"},
 	},
 	{
-		ID:       "stripe-secret-token",
-		Category: CategoryStripe,
-		Title:    "Stripe Secret Key",
-		Severity: "CRITICAL",
-		Regex:    MustCompile(`(?i)sk_(test|live)_[0-9a-z]{10,32}`),
-		Keywords: []string{"sk_test_", "sk_live_"},
+		ID:              "stripe-secret-token",
+		Category:        CategoryStripe,
+		Title:           "Stripe Secret Key",
+		Severity:        "CRITICAL",
+		Regex:           MustCompileWithoutWordPrefix(`?P<secret>(?i)sk_(test|live)_[0-9a-z]{10,32}`),
+		SecretGroupName: "secret",
+		Keywords:        []string{"sk_test_", "sk_live_"},
 	},
 	{
 		ID:       "pypi-upload-token",
@@ -278,7 +313,7 @@ var builtinRules = []Rule{
 		Category:        CategoryAlibaba,
 		Title:           "Alibaba AccessKey ID",
 		Severity:        "HIGH",
-		Regex:           MustCompile(`([^0-9a-z]|^)(?P<secret>(LTAI)(?i)[a-z0-9]{20})([^0-9a-z]|$)`),
+		Regex:           MustCompile(`([^0-9A-Za-z]|^)(?P<secret>(LTAI)(?i)[a-z0-9]{20})([^0-9A-Za-z]|$)`),
 		SecretGroupName: "secret",
 		Keywords:        []string{"LTAI"},
 	},
@@ -481,20 +516,22 @@ var builtinRules = []Rule{
 		Keywords:        []string{"finicity"},
 	},
 	{
-		ID:       "flutterwave-public-key",
-		Category: CategoryFlutterwave,
-		Title:    "Flutterwave public/secret key",
-		Severity: "MEDIUM",
-		Regex:    MustCompile(`FLW(PUB|SEC)K_TEST-(?i)[a-h0-9]{32}-X`),
-		Keywords: []string{"FLWSECK_TEST-", "FLWPUBK_TEST-"},
+		ID:              "flutterwave-public-key",
+		Category:        CategoryFlutterwave,
+		Title:           "Flutterwave public/secret key",
+		Severity:        "MEDIUM",
+		Regex:           MustCompileWithoutWordPrefix(`?P<secret>FLW(PUB|SEC)K_TEST-(?i)[a-h0-9]{32}-X`),
+		SecretGroupName: "secret",
+		Keywords:        []string{"FLWSECK_TEST-", "FLWPUBK_TEST-"},
 	},
 	{
-		ID:       "flutterwave-enc-key",
-		Category: CategoryFlutterwave,
-		Title:    "Flutterwave encrypted key",
-		Severity: "MEDIUM",
-		Regex:    MustCompile(`FLWSECK_TEST[a-h0-9]{12}`),
-		Keywords: []string{"FLWSECK_TEST"},
+		ID:              "flutterwave-enc-key",
+		Category:        CategoryFlutterwave,
+		Title:           "Flutterwave encrypted key",
+		Severity:        "MEDIUM",
+		Regex:           MustCompileWithoutWordPrefix(`?P<secret>FLWSECK_TEST[a-h0-9]{12}`),
+		SecretGroupName: "secret",
+		Keywords:        []string{"FLWSECK_TEST"},
 	},
 	{
 		ID:       "frameio-api-token",
@@ -517,7 +554,7 @@ var builtinRules = []Rule{
 		Category: CategoryGrafana,
 		Title:    "Grafana API token",
 		Severity: "MEDIUM",
-		Regex:    MustCompile(`['\"]eyJrIjoi(?i)[a-z0-9\-_=]{72,92}['\"]`),
+		Regex:    MustCompile(`['\"]?eyJrIjoi(?i)[a-z0-9\-_=]{72,92}['\"]?`),
 		Keywords: []string{"eyJrIjoi"},
 	},
 	{
@@ -562,6 +599,14 @@ var builtinRules = []Rule{
 		Regex:    MustCompile(`(?i)(ionic[a-z0-9_ .\-,]{0,25})(=|>|:=|\|\|:|<=|=>|:).{0,5}['\"](ion_[a-z0-9]{42})['\"]`),
 		Keywords: []string{"ionic"},
 	},
+	{
+		ID:       "jwt-token",
+		Category: CategoryJWT,
+		Title:    "JWT token",
+		Severity: "MEDIUM",
+		Regex:    MustCompile(`ey[a-zA-Z0-9]{17,}\.ey[a-zA-Z0-9\/\\_-]{17,}\.(?:[a-zA-Z0-9\/\\_-]{10,}={0,2})?`),
+		Keywords: []string{".eyJ"},
+	},
 	{
 		ID:       "linear-api-token",
 		Category: CategoryLinear,
@@ -699,6 +744,15 @@ var builtinRules = []Rule{
 		Regex:    MustCompile(`pscale_tkn_(?i)[a-z0-9\-_\.]{43}`),
 		Keywords: []string{"pscale_tkn_"},
 	},
+	{
+		ID:       "private-packagist-token",
+		Category: CategoryPrivatePackagist,
+		Title:    "Private Packagist token",
+		Severity: "HIGH",
+		// https://packagist.com/docs/composer-authentication#token-format
+		Regex:    MustCompile(`packagist_[ou][ru]t_(?i)[a-f0-9]{68}`),
+		Keywords: []string{"packagist_uut_", "packagist_ort_", "packagist_out_"},
+	},
 	{
 		ID:       "postman-api-token",
 		Category: CategoryPostman,
@@ -783,4 +837,13 @@ var builtinRules = []Rule{
 		SecretGroupName: "secret",
 		Keywords:        []string{"typeform"},
 	},
+	{
+		ID:              "dockerconfig-secret",
+		Category:        CategoryDocker,
+		Title:           "Dockerconfig secret exposed",
+		Severity:        "HIGH",
+		Regex:           MustCompile(`(?i)(\.(dockerconfigjson|dockercfg):\s*\|*\s*(?P<secret>(ey|ew)+[A-Za-z0-9\/\+=]+))`),
+		SecretGroupName: "secret",
+		Keywords:        []string{"dockerc"},
+	},
 }
