@@ -1,7 +1,7 @@
 package flag
 
 var (
-	SecretConfigFlag = Flag{
+	SecretConfigFlag = Flag[string]{
 		Name:       "secret-config",
 		ConfigName: "secret.config",
 		Default:    "trivy-secret.yaml",
@@ -10,7 +10,7 @@ var (
 )
 
 type SecretFlagGroup struct {
-	SecretConfig *Flag
+	SecretConfig *Flag[string]
 }
 
 type SecretOptions struct {
@@ -19,7 +19,7 @@ type SecretOptions struct {
 
 func NewSecretFlagGroup() *SecretFlagGroup {
 	return &SecretFlagGroup{
-		SecretConfig: &SecretConfigFlag,
+		SecretConfig: SecretConfigFlag.Clone(),
 	}
 }
 
@@ -27,12 +27,13 @@ func (f *SecretFlagGroup) Name() string {
 	return "Secret"
 }
 
-func (f *SecretFlagGroup) Flags() []*Flag {
-	return []*Flag{f.SecretConfig}
+func (f *SecretFlagGroup) Flags() []Flagger {
+	return []Flagger{f.SecretConfig}
 }
 
-func (f *SecretFlagGroup) ToOptions() SecretOptions {
-	return SecretOptions{
-		SecretConfigPath: getString(f.SecretConfig),
+func (f *SecretFlagGroup) ToOptions(opts *Options) error {
+	opts.SecretOptions = SecretOptions{
+		SecretConfigPath: f.SecretConfig.Value(),
 	}
+	return nil
 }
