@@ -11,9 +11,9 @@ func addFirewallRule(resource azure.Resource) []database.FirewallRule {
 	var rules []database.FirewallRule
 	for _, rule := range resource.Properties.GetMapValue("firewallRules").AsMap() {
 		rules = append(rules, database.FirewallRule{
-			Metadata: rule.Metadata,
-			StartIP:  rule.GetMapValue("startIpAddress").AsStringValue("", rule.Metadata),
-			EndIP:    rule.GetMapValue("endIpAddress").AsStringValue("", rule.Metadata),
+			Metadata: rule.GetMetadata(),
+			StartIP:  rule.GetMapValue("startIpAddress").AsStringValue("", rule.GetMetadata()),
+			EndIP:    rule.GetMapValue("endIpAddress").AsStringValue("", rule.GetMetadata()),
 		})
 	}
 	return rules
