@@ -22,16 +22,12 @@ func Install(ctx context.Context, dir, repo string, quiet bool, opt types.Regist
 		return xerrors.Errorf("repository parse error: %w", err)
 	}
 
-	log.Logger.Infof("Installing the module from %s...", repo)
-	artifact, err := oci.NewArtifact(repo, quiet, opt)
-	if err != nil {
-		return xerrors.Errorf("module initialize error: %w", err)
-	}
+	log.Info("Installing the module from the repository...", log.String("repo", repo))
+	art := oci.NewArtifact(repo, opt)
 
 	dst := filepath.Join(dir, ref.Context().Name())
-	log.Logger.Debugf("Installing the module to %s...", dst)
-
-	if err = artifact.Download(ctx, dst, oci.DownloadOption{MediaType: mediaType}); err != nil {
+	log.Debug("Installing the module...", log.String("dst", dst))
+	if err = art.Download(ctx, dst, oci.DownloadOption{MediaType: mediaType, Quiet: quiet}); err != nil {
 		return xerrors.Errorf("module download error: %w", err)
 	}
 
@@ -45,7 +41,7 @@ func Uninstall(_ context.Context, dir, repo string) error {
 		return xerrors.Errorf("repository parse error: %w", err)
 	}
 
-	log.Logger.Infof("Uninstalling %s ...", repo)
+	log.Info("Uninstalling the module ...", log.String("module", repo))
 	dst := filepath.Join(dir, ref.Context().Name())
 	if err = os.RemoveAll(dst); err != nil {
 		return xerrors.Errorf("remove error: %w", err)
